%define dotnet_version     3.1
%define dotnet_release     rh-dotnet31
%define  instDir           /usr/lib/dotnet/NuPkgs
%define  artifactory       https://artifactory.oci.oraclecorp.com/api/nuget/oci-dex-release-nuget-local


Name:       oci-dotnet-sdk		
Version:	64.2.0
Release: 1%{?dist}
Group:		Oracle Cloud Infrastructure
Summary:    Oracle Cloud Infrastructure SDK for .NET
License:	UPL 1.0 and Apache 2.0 
URL:		https://github.com/oracle/oci-dotnet-sdk
Source0:	%{name}-%{version}.tar.bz2
Source1:    oci-dotnet-sdk.csproj
Source2:    nuget.config
Source3:    name-mapping.txt
Buildarch:  noarch
AutoReq:    no

%if "%{?dist}" == ".el7"
BuildRequires:	%{?dotnet_release}-dotnet >= %{dotnet_version} 
Requires:	    %{?dotnet_release}-dotnet >= %{dotnet_version}
%else
BuildRequires: dotnet-sdk-6.0
Requires:          dotnet-sdk-6.0
%endif

%description
The oci-dotnet-sdk provides Oracle Cloud Infrastructure SDK for .NET 
that you can use to manage your Oracle Cloud Infrastructure resources.

Please add or copy  nuget.config to ~/.config/NuGet/nuget.config
 
%prep
%setup -q

sed -i '/.*tests/,+1d' oci-dotnet-sdk.sln
sed -i '/Examples/,+1d' oci-dotnet-sdk.sln

packFile=oci-dotnet-sdk.csproj
cp %{SOURCE1} .

cspFiles=`ls */*.csproj |grep -v .*tests |grep -v Examples`
for csp in $cspFiles; do 
       pkgName=`basename $csp .csproj`
       echo "    <PackageReference Include=\"${pkgName}\" Version=\"%{version}\" />" >>$packFile
done
echo -n "  </ItemGroup>
</Project>
" >>$packFile


%build
unset https_proxy
unset http_proxy

%if "%{?dist}" == ".el7"
which dotnet ||  source /opt/rh/%{dotnet_release}/enable
%endif
dotnet nuget locals all -c
dotnet restore -s %{artifactory}
mv oci-dotnet-sdk.sln oci-dotnet-sdk.sln.old
dotnet restore -s %{artifactory}


%check 
#make unit-test

%install
mkdir -p %{buildroot}%{instDir}
NuPkgs=`find ~/.nuget/ -name "oci.dotnet*.nupkg"`
for nupkg in $NuPkgs; do
    lastname=`basename $nupkg .%version.nupkg|cut -d. -f3`
    cp $nupkg %{buildroot}%{instDir}/OCI.DotNetSDK.${lastname^}.%version.nupkg
done

cp %{SOURCE3} .
NuPkgs=`find ~/.nuget/ -name "*.nupkg"|grep -v "oci.dotnetsdk"`
for nupkg in $NuPkgs; do
    bnameV=`basename $nupkg .nupkg`
    bname=`echo ${bnameV} |sed 's/\.[0-9].*//i'`
    bVersion=`echo ${bnameV/${bname}./}`
    tName=`grep "$bname" name-mapping.txt |awk '{print $2}'`
    [ "$tName" != "" ] || exit 1
    cp $nupkg %{buildroot}%{instDir}/${tName}.${bVersion}.nupkg
done

cp %{SOURCE2} .

%files
%{instDir}/*
%doc *.md *.txt nuget.config Examples/ 

%pre
instDir=/usr/lib/dotnet/NuPkgs
[ -d $instDir ] ||  mkdir -p $instDir 

%changelog
* Tue Jun 27 2023 EL Errata <el-errata_ww@oracle.com> 64.2.0-1
- Update to 64.2.0

* Tue Jun 20 2023 EL Errata <el-errata_ww@oracle.com> 64.1.0-1
- Update to 64.1.0

* Tue Jun 13 2023 EL Errata <el-errata_ww@oracle.com> 64.0.0-1
- Update to 64.0.0

* Tue Jun 06 2023 EL Errata <el-errata_ww@oracle.com> 63.1.0-1
- Update to 63.1.0

* Tue May 30 2023 EL Errata <el-errata_ww@oracle.com> 63.0.0-1
- Update to 63.0.0

* Tue May 23 2023 EL Errata <el-errata_ww@oracle.com> 62.0.0-1
- Update to 62.0.0

* Tue May 16 2023 EL Errata <el-errata_ww@oracle.com> 61.0.0-1
- Update to 61.0.0

* Tue May 09 2023 EL Errata <el-errata_ww@oracle.com> 60.1.0-1
- Update to 60.1.0

* Tue May 02 2023 EL Errata <el-errata_ww@oracle.com> 60.0.0-1
- Update to 60.0.0

* Tue Apr 25 2023 EL Errata <el-errata_ww@oracle.com> 59.1.0-1
- Update to 59.1.0

* Tue Apr 18 2023 EL Errata <el-errata_ww@oracle.com> 59.0.0-1
- Update to 59.0.0

* Tue Apr 11 2023 EL Errata <el-errata_ww@oracle.com> 58.0.0-1
- Update to 58.0.0

* Tue Apr 04 2023 EL Errata <el-errata_ww@oracle.com> 57.0.0-1
- Update to 57.0.0

* Tue Mar 28 2023 EL Errata <el-errata_ww@oracle.com> 56.1.0-1
- Update to 56.1.0

* Tue Mar 21 2023 EL Errata <el-errata_ww@oracle.com> 56.0.0-1
- Update to 56.0.0

* Tue Mar 14 2023 EL Errata <el-errata_ww@oracle.com> 55.0.0-1
- Update to 55.0.0

* Tue Mar 07 2023 EL Errata <el-errata_ww@oracle.com> 54.0.0-1
- Update to 54.0.0

* Tue Feb 28 2023 EL Errata <el-errata_ww@oracle.com> 53.1.0-1
- Update to 53.1.0

* Tue Feb 21 2023 EL Errata <el-errata_ww@oracle.com> 53.0.0-1
- Update to 53.0.0

* Tue Feb 14 2023 EL Errata <el-errata_ww@oracle.com> 52.1.0-1
- Update to 52.1.0

* Tue Feb 07 2023 EL Errata <el-errata_ww@oracle.com> 52.0.0-1
- Update to 52.0.0

* Tue Jan 31 2023 EL Errata <el-errata_ww@oracle.com> 51.3.0-1
- Update to 51.3.0

* Tue Jan 24 2023 EL Errata <el-errata_ww@oracle.com> 51.2.0-1
- Update to 51.2.0

* Tue Jan 17 2023 EL Errata <el-errata_ww@oracle.com> 51.1.0-1
- Update to 51.1.0

* Tue Dec 13 2022 EL Errata <el-errata_ww@oracle.com> 51.0.0-1
- Update to 51.0.0

* Tue Dec 06 2022 EL Errata <el-errata_ww@oracle.com> 50.0.0-1
- Update to 50.0.0

* Tue Nov 15 2022 EL Errata <el-errata_ww@oracle.com> 49.1.0-1
- Update to 49.1.0

* Tue Nov 08 2022 EL Errata <el-errata_ww@oracle.com> 49.0.0-1
- Update to 49.0.0

* Tue Nov 01 2022 EL Errata <el-errata_ww@oracle.com> 48.0.0-1
- Update to 48.0.0

* Tue Oct 25 2022 EL Errata <el-errata_ww@oracle.com> 47.0.0-1
- Update to 47.0.0

* Tue Oct 04 2022 EL Errata <el-errata_ww@oracle.com> 46.0.0-1
- Update to 46.0.0

* Tue Sep 27 2022 EL Errata <el-errata_ww@oracle.com> 45.1.0-1
- Update to 45.1.0

* Tue Sep 20 2022 EL Errata <el-errata_ww@oracle.com> 45.0.0-1
- Update to 45.0.0

* Tue Sep 13 2022 EL Errata <el-errata_ww@oracle.com> 44.1.0-1
- Update to 44.1.0

* Tue Sep 06 2022 EL Errata <el-errata_ww@oracle.com> 44.0.0-1
- Update to 44.0.0

* Tue Aug 30 2022 EL Errata <el-errata_ww@oracle.com> 43.1.0-1
- Update to 43.1.0

* Tue Aug 23 2022 EL Errata <el-errata_ww@oracle.com> 43.0.0-1
- Update to 43.0.0

* Tue Aug 16 2022 EL Errata <el-errata_ww@oracle.com> 42.1.0-1
- Update to 42.1.0

* Tue Aug 09 2022 EL Errata <el-errata_ww@oracle.com> 42.0.0-1
- Update to 42.0.0

* Tue Aug 02 2022 EL Errata <el-errata_ww@oracle.com> 41.1.0-1
- Update to 41.1.0

* Tue Jul 26 2022 EL Errata <el-errata_ww@oracle.com> 41.0.0-1
- Update to 41.0.0

* Tue Jul 19 2022 EL Errata <el-errata_ww@oracle.com> 40.1.0-1
- Update to 40.1.0

* Tue Jul 12 2022 EL Errata <el-errata_ww@oracle.com> 40.0.0-1
- Update to 40.0.0

* Tue Jul 05 2022 EL Errata <el-errata_ww@oracle.com> 39.3.0-1
- Update to 39.3.0

* Tue Jun 28 2022 EL Errata <el-errata_ww@oracle.com> 39.2.0-1
- Update to 39.2.0

* Tue Jun 21 2022 EL Errata <el-errata_ww@oracle.com> 39.1.0-1
- Update to 39.1.0

* Tue Jun 14 2022 EL Errata <el-errata_ww@oracle.com> 39.0.0-1
- Update to 39.0.0

* Tue Jun 07 2022 EL Errata <el-errata_ww@oracle.com> 38.4.0-1
- Update to 38.4.0

* Tue May 31 2022 EL Errata <el-errata_ww@oracle.com> 38.3.0-1
- Update to 38.3.0

* Tue May 24 2022 EL Errata <el-errata_ww@oracle.com> 38.2.0-1
- Update to 38.2.0

* Tue May 17 2022 EL Errata <el-errata_ww@oracle.com> 38.1.0-1
- Update to 38.1.0

* Tue May 10 2022 EL Errata <el-errata_ww@oracle.com> 38.0.0-1
- Update to 38.0.0

* Tue May 03 2022 EL Errata <el-errata_ww@oracle.com> 37.1.0-1
- Update to 37.1.0

* Tue Apr 26 2022 EL Errata <el-errata_ww@oracle.com> 37.0.0-1
- Update to 37.0.0

* Tue Apr 19 2022 EL Errata <el-errata_ww@oracle.com> 36.0.0-1
- Update to 36.0.0

* Tue Apr 12 2022 EL Errata <el-errata_ww@oracle.com> 35.1.0-1
- Update to 35.1.0

* Tue Apr 05 2022 EL Errata <el-errata_ww@oracle.com> 35.0.0-1
- Update to 35.0.0

* Tue Mar 29 2022 EL Errata <el-errata_ww@oracle.com> 34.2.0-1
- Update to 34.2.0

* Tue Mar 22 2022 EL Errata <el-errata_ww@oracle.com> 34.1.0-1
- Update to 34.1.0

* Tue Mar 15 2022 EL Errata <el-errata_ww@oracle.com> 34.0.0-1
- Update to 34.0.0

* Tue Mar 08 2022 EL Errata <el-errata_ww@oracle.com> 33.0.0-1
- Update to 33.0.0

* Tue Mar 01 2022 EL Errata <el-errata_ww@oracle.com> 32.2.0-1
- Update to 32.2.0

* Tue Feb 22 2022 EL Errata <el-errata_ww@oracle.com> 32.1.0-1
- Update to 32.1.0

* Tue Feb 15 2022 EL Errata <el-errata_ww@oracle.com> 32.0.0-1
- Update to 32.0.0

* Tue Feb 08 2022 EL Errata <el-errata_ww@oracle.com> 31.0.0-1
- Update to 31.0.0

* Tue Feb 01 2022 EL Errata <el-errata_ww@oracle.com> 30.3.0-1
- Update to 30.3.0

* Tue Jan 25 2022 EL Errata <el-errata_ww@oracle.com> 30.2.0-1
- Update to 30.2.0

* Tue Jan 18 2022 EL Errata <el-errata_ww@oracle.com> 30.1.0-1
- Update to 30.1.0

* Tue Dec 14 2021 EL Errata <el-errata_ww@oracle.com> 29.4.0-1
- Update to 29.4.0

* Tue Dec 07 2021 EL Errata <el-errata_ww@oracle.com> 29.3.0-1
- Update to 29.3.0

* Tue Nov 30 2021 EL Errata <el-errata_ww@oracle.com> 29.2.0-1
- Update to 29.2.0

* Wed Nov 17 2021 EL Errata <el-errata_ww@oracle.com> 29.1.0-1
- Update to 29.1.0

* Tue Nov 09 2021 EL Errata <el-errata_ww@oracle.com> 29.0.0-1
- Update to 29.0.0

* Tue Nov 02 2021 EL Errata <el-errata_ww@oracle.com> 28.1.0-1
- Update to 28.1.0

* Tue Oct 26 2021 EL Errata <el-errata_ww@oracle.com> 28.0.0-1
- Update to 28.0.0

* Tue Oct 19 2021 EL Errata <el-errata_ww@oracle.com> 27.2.0-1
- Update to 27.2.0

* Tue Oct 12 2021 EL Errata <el-errata_ww@oracle.com> 27.1.0-1
- Update to 27.1.0

* Tue Oct 05 2021 EL Errata <el-errata_ww@oracle.com> 27.0.0-1
- Update to 27.0.0

* Tue Sep 28 2021 EL Errata <el-errata_ww@oracle.com> 26.0.0-1
- Update to 26.0.0

* Tue Sep 14 2021 EL Errata <el-errata_ww@oracle.com> 25.1.0-1
- Update to 25.1.0

* Tue Sep 07 2021 EL Errata <el-errata_ww@oracle.com> 25.0.0-1
- Update to 25.0.0

* Tue Aug 31 2021 EL Errata <el-errata_ww@oracle.com> 24.2.0-1
- Update to 24.2.0

* Tue Aug 24 2021 EL Errata <el-errata_ww@oracle.com> 24.1.0-1
- Update to 24.1.0

* Tue Aug 17 2021 EL Errata <el-errata_ww@oracle.com> 24.0.0-1
- Update to 24.0.0

* Tue Aug 03 2021 EL Errata <el-errata_ww@oracle.com> 23.2.0-1
- Update to 23.2.0

* Tue Jul 27 2021 EL Errata <el-errata_ww@oracle.com> 23.1.0-1
- Update to 23.1.0

* Tue Jul 20 2021 EL Errata <el-errata_ww@oracle.com> 23.0.0-1
- Update to 23.0.0

* Tue Jul 13 2021 EL Errata <el-errata_ww@oracle.com> 22.0.0-1
- Update to 22.0.0

* Tue Jul 06 2021 EL Errata <el-errata_ww@oracle.com> 21.1.0-1
- Update to 21.1.0

* Tue Jun 29 2021 EL Errata <el-errata_ww@oracle.com> 21.0.0-1
- Update to 21.0.0

* Tue Jun 22 2021 EL Errata <el-errata_ww@oracle.com> 20.1.0-1
- Update to 20.1.0

* Tue Jun 15 2021 EL Errata <el-errata_ww@oracle.com> 20.0.0-1
- Update to 20.0.0

* Tue Jun 08 2021 EL Errata <el-errata_ww@oracle.com> 19.2.0-1
- Update to 19.2.0

* Tue Jun 01 2021 EL Errata <el-errata_ww@oracle.com> 19.1.0-1
- Update to 19.1.0

* Tue May 25 2021 EL Errata <el-errata_ww@oracle.com> 19.0.0-1
- Update to 19.0.0

* Tue May 18 2021 EL Errata <el-errata_ww@oracle.com> 18.5.0-1
- Update to 18.5.0

* Tue May 11 2021 EL Errata <el-errata_ww@oracle.com> 18.4.0-1
- Update to 18.4.0

* Tue May 04 2021 EL Errata <el-errata_ww@oracle.com> 18.3.0-1
- Update to 18.3.0

* Tue Apr 27 2021 EL Errata <el-errata_ww@oracle.com> 18.2.0-1
- Update to 18.2.0

* Tue Apr 20 2021 EL Errata <el-errata_ww@oracle.com> 18.1.0-1
- Update to 18.1.0

* Tue Apr 13 2021 EL Errata <el-errata_ww@oracle.com> 18.0.0-1
- Update to 18.0.0

* Tue Apr 06 2021 EL Errata <el-errata_ww@oracle.com> 17.1.0-1
- Update to 17.1.0

* Tue Mar 30 2021 EL Errata <el-errata_ww@oracle.com> 17.0.0-1
- Update to 17.0.0

* Tue Mar 23 2021 EL Errata <el-errata_ww@oracle.com> 16.0.0-1
- Update to 16.0.0

* Tue Mar 16 2021 EL Errata <el-errata_ww@oracle.com> 15.2.0-1
- Update to 15.2.0

* Tue Mar 09 2021 EL Errata <el-errata_ww@oracle.com> 15.1.0-1
- Update to 15.1.0

* Tue Mar 02 2021 EL Errata <el-errata_ww@oracle.com> 15.0.0-1
- Update to 15.0.0

* Tue Feb 23 2021 EL Errata <el-errata_ww@oracle.com> 14.2.0-1
- Update to 14.2.0

* Tue Feb 16 2021 EL Errata <el-errata_ww@oracle.com> 14.1.0-1
- Update to 14.1.0

* Tue Feb 09 2021 EL Errata <el-errata_ww@oracle.com> 14.0.0-1
- Update to 14.0.0

* Tue Feb 02 2021 EL Errata <el-errata_ww@oracle.com> 13.0.0-1
- Update to 13.0.0

* Tue Jan 26 2021 EL Errata <el-errata_ww@oracle.com> 12.0.0-1
- Update to 12.0.0

* Tue Jan 19 2021 EL Errata <el-errata_ww@oracle.com> 11.0.0-1
- Update to 11.0.0

* Tue Jan 12 2021 EL Errata <el-errata_ww@oracle.com> 10.0.0-1
- Update to 10.0.0

* Tue Dec 15 2020 EL Errata <el-errata_ww@oracle.com> 9.0.0-1
- Update to 9.0.0

* Tue Dec 08 2020 EL Errata <el-errata_ww@oracle.com> 8.1.0-1
- Update to 8.1.0

* Tue Dec 01 2020 EL Errata <el-errata_ww@oracle.com> 8.0.0-1
- Update to 8.0.0

* Tue Nov 17 2020 EL Errata <el-errata_ww@oracle.com> 7.0.0-1
- Update to 7.0.0

* Tue Nov 10 2020 EL Errata <el-errata_ww@oracle.com> 6.2.0-1
- Update to 6.2.0

* Mon Nov 09 2020 EL Errata <el-errata_ww@oracle.com> 6.1.0-1.0.1
- Remove Examples from build
- Add <clear /> to nuget.config

* Tue Nov 03 2020 EL Errata <el-errata_ww@oracle.com> 6.1.0-1
- Update to 6.1.0

* Tue Oct 27 2020 EL Errata <el-errata_ww@oracle.com> 6.0.0-1
- Update to 6.0.0

* Tue Oct 20 2020 EL Errata <el-errata_ww@oracle.com> 5.1.0-1
- Update to 5.1.0

* Wed Oct 14 2020 Qing Lin <qing.lin@oracle.com> - 5.0.1-1.el7
- update to 5.0.1

* Wed Oct 14 2020 Qing Lin <qing.lin@oracle.com> -5.0.1-1 
- Build for first RPM release.

* Mon Oct 12 2020 Qing Lin <qing.lin@oracle.com> -4.7.0-1 
- Update to 4.7.0.

* Mon Sep 21 2020 Qing Lin <qing.lin@oracle.com> -4.3.0-1.0.1 
- Pack the prebuild OCI.DotNetSDK nupkgs from OCI artifactory instead.

* Fri Sep 11 2020 Qing Lin <qing.lin@oracle.com> -4.3.0-1 
- Update to 4.3.0
- Add dependency system.identitymodel.tokens.jwt.6.7.1.nupkg
- And its dependencies: system.security.cryptography.cng, microsoft.identitymodel.logging, tokens, jsonwetokens

* Fri Aug 28 2020 Qing Lin <qing.lin@oracle.com> -4.1.0 
- Initial build

